@@ -3,7 +3,7 @@
 
 #include "options.h"
 #include "help.h"
-#include "parse.h"
+#include "dataquery.h"
 
 
 int main(int argc, char *argv[]) {
@@ -23,9 +23,12 @@ int main(int argc, char *argv[]) {
     auto optionsResult = Options::getOptions(argc, argv);
 
     if (optionsResult.has_value()) {
-        auto [jsonText, query] = optionsResult.value();
+        auto [jsonText, query, condition] = optionsResult.value();
 
-        auto dictQueryResult = Parse::dictQuery(jsonText, query);
+        auto [
+            valueType,
+            dictQueryResult
+            ] = DataQuery::dataQuery(jsonText, query, condition);
 
         std::cout << dictQueryResult << std::endl;
     } else {
